==> orchestra-api-4.0.10-sources.jar: org/ow2/orchestra/facade/data/def/CompensateScopeActivityDefinitionData.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.data.def;

import org.ow2.orchestra.facade.runtime.ActivityType;
import org.ow2.orchestra.facade.uuid.ActivityDefinitionUUID;

/**
 * @author S. Ali Tokmen
 */
public class CompensateScopeActivityDefinitionData extends ActivityDefinitionData {

  private static final long serialVersionUID = 7525820665307384841L;

  private String target;

  public CompensateScopeActivityDefinitionData(final ProcessDefinitionData processDefinitionData, final ActivityDefinitionUUID uuid,
    final ActivityDefinitionUUID encloserUUID, final String name, final String target) {
    super(processDefinitionData, uuid, encloserUUID, ActivityType.COMPENSATE_SCOPE, name);
    this.target = target;
  }

  /**
   * @return The target attribute of the compensateScope activity (mandatory).
   */
  public String getTarget() {
    return target;
  }

}

==> orchestra-api-4.1.0-sources.jar: org/ow2/orchestra/facade/data/def/CompensateScopeActivityDefinitionData.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.data.def;

import org.ow2.orchestra.facade.runtime.ActivityType;
import org.ow2.orchestra.facade.uuid.ActivityDefinitionUUID;

/**
 * @author S. Ali Tokmen
 */
public class CompensateScopeActivityDefinitionData extends ActivityDefinitionData {

  private final String target;

  public CompensateScopeActivityDefinitionData(final ProcessDefinitionData processDefinitionData, final ActivityDefinitionUUID uuid,
    final ActivityDefinitionUUID encloserUUID, final String name, final String target) {
    super(processDefinitionData, uuid, encloserUUID, ActivityType.COMPENSATE_SCOPE, name);
    this.target = target;
  }

  /**
   * @return The target attribute of the compensateScope activity (mandatory).
   */
  public String getTarget() {
    return this.target;
  }

}
